parley.controllers.tasklet

# Module parley.controllers.tasklet

## Classes

`class ChannelWrapper:`

>     Wraps stackless channels to give them a queue-like interface.

> `def get(self):`

> `def get_nowait(self):`

> `def put(self, data):`

`class TaskletActor(parley.actor.AbstractActor):`

> `QueueClass = <class parley.controllers.tasklet.WackyChannelWrapper>`

> `def _handle_signal(self, signal):`

> >     If this function is called, we know that a signal is waiting.
> >     Depending on the value of self.trap_exceptions, we either
> >     raise the signal as an exception or return it as a message.

> > Overrides: parley.actor.AbstractActor

> `def _next_message(self, msg_filter, wait):`

> > Overrides: parley.actor.AbstractActor

> `def go(self):`

> > Overrides: parley.actor.AbstractActor

> `def recv(self, msg_filter=None, wait=True):`

> > Overrides: parley.actor.AbstractActor

> `def register_id(self):`

> > Overrides: parley.actor.AbstractActor

> `def run(self):`

> > Overrides: parley.actor.AbstractActor

`class TaskletController(parley.controller.AbstractController):`

> `ActorClass = <class 'parley.controllers.tasklet.TaskletActor'>`

> `def _create_link(self, a, b):`

> > Overrides: parley.controller.AbstractController

> `def _current_actor(self):`

> > Overrides: parley.controller.AbstractController

> `def _current_actor_id(self):`

> > Overrides: parley.controller.AbstractController

> `def _current_actor_proxy(self):`

> > Overrides: parley.controller.AbstractController

> `def _quit(self, actor_id):`

> > Overrides: parley.controller.AbstractController

> `def _remove_link(self, a, b):`

> > Overrides: parley.controller.AbstractController

> `def _spawn(self, target, args, kwargs, link=False):`

> > Overrides: parley.controller.AbstractController

> `def alert_exception(self, origin_id, e):`

> > Overrides: parley.controller.AbstractController

> `def alert_quit(self, origin_id):`

> > Overrides: parley.controller.AbstractController

> `def link(self, target):`

> > Overrides: parley.controller.AbstractController

> `def lookup(self, name):`

> > Overrides: parley.controller.AbstractController

> `def register(self, actor_proxy, name):`

> > Overrides: parley.controller.AbstractController

> `def send(self, target_id, msg):`

> > Overrides: parley.controller.AbstractController

> `def send_signal(self, target_id, msg):`

> > Overrides: parley.controller.AbstractController

> `def spawn(self, target, *args, **kwargs):`

> > Overrides: parley.controller.AbstractController

> `def spawn_link(self, target, *args, **kwargs):`

> > Overrides: parley.controller.AbstractController

> `def unlink(self, target):`

> > Overrides: parley.controller.AbstractController

> `def unregister(self, name):`

> > Overrides: parley.controller.AbstractController

`class WackyChannelWrapper:`

>     Wraps stackless channels to give them a queue-like interface.

> `def get(self):`

> `def get_nowait(self):`

> `def put(self, data):`

## Other

`stackless = <module 'stackless' (built-in)>`